@@ -5,7 +5,7 @@ from adapay_merchant.api.request_tools import request_post, pay_message_token
 
 
 def get_message_manager():
-    expire_time = 30_000_000_000
+    expire_time = 30000000000
     data = request_post(pay_message_token, {'expire_time': expire_time})
 
     if 'succeeded' != data.get('status'):
